/**
 * This file is released under the GNU General Public License.
 * Refer to the COPYING file distributed with this package.
 *
 * Copyright (c) 2008-2010 WURFL-Pro srl
 */

package net.sourceforge.wurfl.core.handlers.matchers;

import java.util.LinkedHashMap;
import java.util.Map;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

import org.apache.commons.collections.CollectionUtils;

import net.sourceforge.wurfl.core.Constants;
import net.sourceforge.wurfl.core.handlers.Handler;
import net.sourceforge.wurfl.core.handlers.classifiers.FilteredDevices;
import net.sourceforge.wurfl.core.request.WURFLRequest;
import net.sourceforge.wurfl.core.utils.Predicates;

/**
 * @author Fantayeneh Asres Gizaw
 * @author Filippo De Luca
 * @version $Id: BlackBerryMatcher.java 544 2010-09-30 11:34:38Z asres.fantayeneh $
 */
public class BlackBerryMatcher extends AbstractMatcher {

    public BlackBerryMatcher(Handler handler) {
        super(handler);
    }

    private static final Map BLACKBERRIES = new LinkedHashMap();

    static {
        BLACKBERRIES.put("2.", "blackberry_generic_ver2");
        BLACKBERRIES.put("3.2", "blackberry_generic_ver3_sub2");
        BLACKBERRIES.put("3.3", "blackberry_generic_ver3_sub30");
        BLACKBERRIES.put("3.5", "blackberry_generic_ver3_sub50");
        BLACKBERRIES.put("3.6", "blackberry_generic_ver3_sub60");
        BLACKBERRIES.put("3.7", "blackberry_generic_ver3_sub70");
        BLACKBERRIES.put("4.1", "blackberry_generic_ver4_sub10");
        BLACKBERRIES.put("4.2", "blackberry_generic_ver4_sub20");
        BLACKBERRIES.put("4.3", "blackberry_generic_ver4_sub30");
        BLACKBERRIES.put("4.5", "blackberry_generic_ver4_sub50");
        BLACKBERRIES.put("4.6", "blackberry_generic_ver4_sub60");
        BLACKBERRIES.put("4.7", "blackberry_generic_ver4_sub70");
        BLACKBERRIES.put("4.", "blackberry_generic_ver4");
        BLACKBERRIES.put("5.", "blackberry_generic_ver5");
        BLACKBERRIES.put("6.", "blackberry_generic_ver6");

    }

    protected String applyRecoveryMatch(WURFLRequest request, FilteredDevices filteredDevices) {
        String userAgent = request.getUserAgent();
        final String version = blackberryOsVersion(userAgent);
        if(version == null) {
            return Constants.GENERIC;
        }
        String key = (String) CollectionUtils.find(BLACKBERRIES.keySet(), Predicates.isContainedIn(version));
        if (key != null) {
            return (String) BLACKBERRIES.get(key);
        }

        return Constants.GENERIC;


    }

    private static final Pattern BLACKBERRY_OS_VERSION_PATTERN = Pattern.compile("Black[Bb]erry[^/\\s]+/(\\d.\\d)");
    private String blackberryOsVersion(String userAgent) {
       Matcher matcher = BLACKBERRY_OS_VERSION_PATTERN.matcher(userAgent);
       return matcher.find() ? matcher.group(1) : null;
    }

}
