package net.sourceforge.wurfl.core.request;

import javax.servlet.http.HttpServletRequest;

import org.apache.commons.lang.StringUtils;
import org.apache.commons.lang.Validate;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import net.sourceforge.wurfl.core.utils.UserAgentUtils;

/**
 * @author: Fantayeneh Asres Gizaw
 */
public class FastWURFLRequestFactory implements WURFLRequestFactory {

    /**
     * Logger
     */
    private static final Log LOG = LogFactory.getLog(FastWURFLRequestFactory.class);

    /**
     * User-Agent resolver
     */
    private final UserAgentResolver userAgentResolver;


    public FastWURFLRequestFactory() {
        this(new DefaultUserAgentResolver());
    }

    public FastWURFLRequestFactory(UserAgentResolver userAgentResolver) {
        this.userAgentResolver = userAgentResolver;
    }

    /**
     * Create a instance of {@link DefaultWURFLRequest} from an instance of
     * {@link HttpServletRequest}.
     * <p/>
     * <p>
     * Uses UserAgentResolver to resolve request user-agent and
     * </p>
     *
     * @param sourceRequest The HttpServletRequest from which build the WURFLRequest.
     */
    public WURFLRequest createRequest(HttpServletRequest sourceRequest) {

        Validate.notNull(sourceRequest, "The sourceRequest must be not null");

        String userAgent = StringUtils.trimToEmpty(userAgentResolver
                .resolve(sourceRequest));

        String uaProf = UserAgentUtils.getUaProfile(sourceRequest);

        DefaultWURFLRequest request = new DefaultWURFLRequest(userAgent, uaProf);

        if (LOG.isDebugEnabled()) {
            LOG.debug("Created DefaultWURFLRequest: " + request);
        }

        return request;
    }

    /**
     * Create a instance of {@link DefaultWURFLRequest} from an instance of
     * {@link HttpServletRequest}.
     * <p/>
     *
     * @param userAgent The User-Agent from which build the WURFLRequest.
     */
    public WURFLRequest createRequest(final String userAgent) {

        String ua = StringUtils.trimToEmpty(userAgent);
        return new DefaultWURFLRequest(ua, null);
    }
}
