/**
 * This file is released under the GNU General Public License.
 * Refer to the COPYING file distributed with this package.
 *
 * Copyright (c) 2008-2010 WURFL-Pro srl
 */

package net.sourceforge.wurfl.core.request.normalizer.generic;

import java.util.regex.Matcher;
import java.util.regex.Pattern;

import net.sourceforge.wurfl.core.request.normalizer.UserAgentNormalizer;

/**
 * Yahoo Babelfish normalizer.
 * 
 * <p>
 * Strips out the "via babelfish.yahoo.com" from the user-agent.
 * </p>
 * 
 * @author Fantayeneh Asres Gizaw
 * @author Filippo De Luca
 * 
 * @version $Id: BabelFishNormalizer.java 544 2010-09-30 11:34:38Z asres.fantayeneh $
 */
public class BabelFishNormalizer implements UserAgentNormalizer {

	private static final Pattern BABEL_FISH_PATTERN = Pattern
			.compile("\\s*\\(via babelfish.yahoo.com\\)\\s*");

    /**
	 * Replace the "via babelfish.yahoo.com" with "".
	 */
	public String normalize(String userAgent) {

		Matcher matcher = BABEL_FISH_PATTERN.matcher(userAgent);
		return matcher.replaceAll("");

	}

}
